@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: path-pieces
 version: 0.2.1
-id: path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-key: pathp_Idrdy6ATKgw33OZB8mjFUB
+id: path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
+key: pathp_4qW9xznk5mC6aJZVVgmWEO
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: unstable
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/path-pieces-0.2.1
-hs-libraries: HSpath-pieces-0.2.1-Idrdy6ATKgw33OZB8mjFUB
+hs-libraries: HSpath-pieces-0.2.1-4qW9xznk5mC6aJZVVgmWEO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
 haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
 haddock-html: /usr/share/doc/haskell-path-pieces/html
